==> matchms-0.24.0.tar.gz: matchms-0.24.0/matchms/importing/load_from_mgf.py <==
import ast
from typing import Generator, TextIO, Union
import numpy as np
from pyteomics.mgf import MGF
from ..Spectrum import Spectrum


def load_from_mgf(filename: Union[str, TextIO],
                  metadata_harmonization: bool = True) -> Generator[Spectrum, None, None]:
    """Load spectrum(s) from mgf file.

    This function will create ~matchms.Spectrum for every spectrum in the given
    .mgf file (or the file-like object).

    Examples:

    .. code-block:: python

        from matchms.importing import load_from_mgf

        file_mgf = "pesticides.mgf"
        spectra_from_path = list(load_from_mgf(file_mgf))

        # Or you can read the file in your application
        with open(file_mgf, 'r') as spectra_file:
            spectra_from_file = list(load_from_mgf(spectra_file))

    Parameters
    ----------
    filename:
        Accepts both filename (with path) for .mgf file or a file-like
        object from a preloaded MGF file.
    metadata_harmonization : bool, optional
        Set to False if metadata harmonization to default keys is not desired.
        The default is True.
    """
    with open(filename, 'r', encoding='utf-8') as file:
        for pyteomics_spectrum in MGF(file, convert_arrays=1):

            metadata = pyteomics_spectrum.get("params", None)
            mz = pyteomics_spectrum["m/z array"]
            intensities = pyteomics_spectrum["intensity array"]
            if "peak_comments" in metadata.keys():
                metadata["peak_comments"] = ast.literal_eval(str(metadata["peak_comments"]))

            # Sort by mz (if not sorted already)
            if not np.all(mz[:-1] <= mz[1:]):
                idx_sorted = np.argsort(mz)
                mz = mz[idx_sorted]
                intensities = intensities[idx_sorted]

            yield Spectrum(mz=mz,
                           intensities=intensities,
                           metadata=metadata,
                           metadata_harmonization=metadata_harmonization)

==> matchms-0.26.0.tar.gz: matchms-0.26.0/matchms/importing/load_from_mgf.py <==
import os
from typing import Generator, TextIO, Union
from pyteomics.mgf import MGF
from matchms.importing.parsing_utils import parse_spectrum_dict
from matchms.Spectrum import Spectrum


def load_from_mgf(filename: Union[str, TextIO],
                  metadata_harmonization: bool = True) -> Generator[Spectrum, None, None]:
    """Load spectrum(s) from mgf file.

    This function will create ~matchms.Spectrum for every spectrum in the given
    .mgf file (or the file-like object).

    Examples:

    .. code-block:: python

        from matchms.importing import load_from_mgf

        file_mgf = "pesticides.mgf"
        spectra_from_path = list(load_from_mgf(file_mgf))

        # Or you can read the file in your application
        with open(file_mgf, 'r') as spectra_file:
            spectra_from_file = list(load_from_mgf(spectra_file))

    Parameters
    ----------
    filename:
        Accepts both filename (with path) for .mgf file or a file-like
        object from a preloaded MGF file.
    metadata_harmonization : bool, optional
        Set to False if metadata harmonization to default keys is not desired.
        The default is True.
    """
    if not os.path.isfile(filename):
        raise FileNotFoundError(f"The specified file: {filename} doesn't exist.") 
    
    def parse_file():
        with MGF(filename, convert_arrays=1) as reader:
            for pyteomics_spectrum in reader:
                yield parse_spectrum_dict(
                    spectrum=pyteomics_spectrum,
                    metadata_harmonization=metadata_harmonization)
    
    return parse_file()
